@@ -21,23 +21,23 @@
 #include "archivestorage.h"
 #include "importexportprogressindicatorbase.h"
 
-#include "mail/exportmailjob.h"
-#include "mail/importmailjob.h"
+#include "mail/exportmailjobinterfaceimpl.h"
+#include "mail/importmailjobinterfaceimpl.h"
 
-#include "addressbook/exportaddressbookjob.h"
-#include "addressbook/importaddressbookjob.h"
+#include "addressbook/exportaddressbookjobinterfaceimpl.h"
+#include "addressbook/importaddressbookjobinterfaceimpl.h"
 
-#include "calendar/exportcalendarjob.h"
-#include "calendar/importcalendarjob.h"
+#include "calendar/importcalendarjobinterfaceimpl.h"
+#include "calendar/exportcalendarjobinterfaceimpl.h"
 
-#include "alarm/exportalarmjob.h"
-#include "alarm/importalarmjob.h"
+#include "alarm/exportalarmjobinterfaceimpl.h"
+#include "alarm/importalarmjobinterfaceimpl.h"
 
-#include "notes/exportnotesjob.h"
-#include "notes/importnotesjob.h"
+#include "notes/exportnotesjobinterfaceimpl.h"
+#include "notes/importnotesjobinterfaceimpl.h"
 
-#include "akregator/exportakregatorjob.h"
-#include "akregator/importakregatorjob.h"
+#include "akregator/exportakregatorjobinterface.h"
+#include "akregator/importakregatorjobinterface.h"
 
 #include <KLocalizedString>
 #include <QFile>
@@ -110,7 +110,7 @@ bool PimDataBackupRestore::backupStart(const QString &filename)
     Utils::addVersion(mArchiveStorage->archive());
     //Add exported file info.
     //qDebug() << "mExportedInfoFileName" << mExportedInfoFileName;
-    Utils::storeDataExportInfo(mExportedInfoFileName, mArchiveStorage->archive());
+    Utils::storeDataExportInfo(mArchiveStorage->archive());
     backupNextStep();
     return true;
 }
@@ -134,37 +134,37 @@ void PimDataBackupRestore::backupNextStep()
         switch (mStoreIterator.key()) {
         case Utils::KMail:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportMailJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportMailJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KAddressBook:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportAddressbookJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportAddressbookJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KAlarm:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportAlarmJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportAlarmJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KOrganizer:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportCalendarJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportCalendarJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KNotes:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportNotesJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportNotesJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::Akregator:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ExportAkregatorJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ExportAkregatorJobInterface(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
@@ -205,37 +205,37 @@ void PimDataBackupRestore::restoreNextStep()
         switch (mStoreIterator.key()) {
         case Utils::KMail:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportMailJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportMailJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KAddressBook:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportAddressbookJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportAddressbookJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KAlarm:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportAlarmJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportAlarmJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KOrganizer:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportCalendarJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportCalendarJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::KNotes:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportNotesJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportNotesJobInterfaceImpl(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
         case Utils::Akregator:
             if (mStoreIterator.value().numberSteps != 0) {
-                mImportExportData = new ImportAkregatorJob(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
+                mImportExportData = new ImportAkregatorJobInterface(this, mStoreIterator.value().types, mArchiveStorage, mStoreIterator.value().numberSteps);
                 executeJob();
             }
             break;
